/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.qa.jdg.bz837362;

import java.io.IOException;
import java.net.InetAddress;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.NameCallback;
import javax.security.auth.callback.PasswordCallback;
import javax.security.auth.callback.UnsupportedCallbackException;
import javax.security.sasl.RealmCallback;

import org.jboss.as.controller.client.ModelControllerClient;
import org.jboss.dmr.ModelNode;

/**
 * 
 * Verify https://bugzilla.redhat.com/show_bug.cgi?id=837362
 * 
 * @author <a href="mailto:mlinhard@redhat.com">Michal Linhard</a>
 * @version Aug 9, 2012
 */
public class Verify {

   private static ModelControllerClient createClient(final InetAddress host, final int port, final String username, final String password,
            final String securityRealmName) {

      final CallbackHandler callbackHandler = new CallbackHandler() {

         public void handle(Callback[] callbacks) throws IOException, UnsupportedCallbackException {
            for (Callback current : callbacks) {
               if (current instanceof NameCallback) {
                  NameCallback ncb = (NameCallback) current;
                  ncb.setName(username);
               } else if (current instanceof PasswordCallback) {
                  PasswordCallback pcb = (PasswordCallback) current;
                  pcb.setPassword(password.toCharArray());
               } else if (current instanceof RealmCallback) {
                  RealmCallback rcb = (RealmCallback) current;
                  rcb.setText(rcb.getDefaultText());
               } else {
                  throw new UnsupportedCallbackException(current);
               }
            }
         }
      };

      return ModelControllerClient.Factory.create(host, port, callbackHandler);
   }

   public static void main(String[] args) throws Exception {
      
      // before starting the test add management user mlinhard password heslo with bin/add-user.sh
      ModelControllerClient client = createClient(InetAddress.getByName("localhost"), 9999, "mlinhard", "heslo", "ManagementRealm");

      // read-resource operation
      ModelNode op = new ModelNode();
      op.get("operation").set("read-resource");
      ModelNode address = op.get("address");
      address.add("subsystem", "infinispan");
      address.add("cache-container", "local");
      address.add("local-cache", "default");
      
      ModelNode returnVal = client.execute(op);
      System.out.println(returnVal.toString());

      // read-attribute operation
      ModelNode op2 = new ModelNode();
      op2.get("operation").set("read-attribute");
      op2.get("name").set("module");
      ModelNode address2 = op2.get("address");
      address2.add("subsystem", "infinispan");
      address2.add("cache-container", "local");
      address2.add("local-cache", "default");

      returnVal = client.execute(op2);
      System.out.println(returnVal.toString());
      client.close();
   }
}
